package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.ProductDto;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.ProductFormVo;
import com.caimei365.commodity.service.ShopService;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/16
 */
@Api(tags="供应商商品API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/shop")
public class ProductShopApi {
    private final ShopService shopService;

    /**
     * 供应商-主推商品
     */
    @ApiOperation("供应商-主推商品（旧：/supplier/home/products）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "shopId", value = "供应商Id（旧：supplierId）"),
        @ApiImplicitParam(required = false, name = "identity", value = "用户身份：1协销，2会员机构，3供应商，4普通机构")
    })
    @GetMapping("/product/main")
    public ResponseJson<List<ProductListVo>> getSupplierMainProducts(Integer shopId, @RequestParam(value = "identity", defaultValue = "0") Integer identity) {
        return shopService.getMainProducts(shopId, identity);
    }

    /**
     * 供应商-我的商品列表
     */
    @ApiOperation("供应商-我的商品（旧：/supplier/myProduct）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "shopId", value = "供应商Id"),
        @ApiImplicitParam(required = false, name = "name", value = "商品名称"),
        @ApiImplicitParam(required = false, name = "productCode", value = "货号"),
        @ApiImplicitParam(required = false, name = "validFlag", value = "状态：0逻辑删除，1待审核，2已上架，3已下架，8审核未通过，9已隐身，10已冻结"),
        @ApiImplicitParam(required = false, name = "featuredFlag", value = "是否主推：0否，1是"),
        @ApiImplicitParam(required = false, name = "commodityType", value = "商品属性：1产品，2仪器"),
        @ApiImplicitParam(required = false, name = "bigTypeId", value = "一级分类Id"),
        @ApiImplicitParam(required = false, name = "smallTypeId", value = "二级分类Id"),
        @ApiImplicitParam(required = false, name = "tinyTypeId", value = "三级级分类Id"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/list")
    public ResponseJson<Map<String, Object>> getShopProducts(Integer shopId, String name, String productCode,
                                                             Integer validFlag, Integer featuredFlag, Integer commodityType, Integer bigTypeId, Integer smallTypeId, Integer tinyTypeId,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                             @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return shopService.getShopProducts(shopId, name, productCode, validFlag, featuredFlag, commodityType, bigTypeId, smallTypeId, tinyTypeId, pageNum, pageSize);
    }

    /**
     * 供应商-发布商品
     *
     * @param productDto {
     *                   aliasName	    内部商品名称
     *                   allAreaFlag	销售区域：1全部区域， 0指定区域
     *                   bigTypeId	    一级分类id
     *                   brandId	    品牌id
     *                   brandName	    品牌名称
     *                   commodityType	商品属性：1产品，2仪器
     *                   costPrice	    成本价
     *                   detailInfo	    商品详情信息
     *                   includedTax	是否含税：0不含税，1含税，2未知
     *                   invoiceType	发票类型
     *                   machineType	械字号类型
     *                   minBuyNumber	最小购买量
     *                   name	        商品名称
     *                   normalPrice	市场价
     *                   orderInfo	    订购方案
     *                   price	        机构价格
     *                   productCode	商品货号
     *                   productType	商品类型：0其它，1妆字号，2械字号
     *                   provinceIds	指定的销售区域
     *                   qualificationImg 械字号资质证书图
     *                   searchKey	      搜索关键词
     *                   serviceInfo	  服务详情
     *                   shopId	         供应商id
     *                   smallTypeId	 二级分类id
     *                   step	         购买数量
     *                   stock	         库存
     *                   tags	         商品标签，逗号隔开
     *                   taxPoint	     开票税点
     *                   tinyTypeId	     三级分类id
     *                   unit	         包装规格
     *                   }
     */
    @ApiOperation("供应商-发布商品（旧：/supplier/releaseProduct）")
    @PostMapping("/product/release")
    public ResponseJson releaseProduct(ProductDto productDto){
        return shopService.releaseProduct(productDto);
    }

    /**
     * 供应商-商品编辑回显
     *
     * @param productId 商品Id
     */
    @ApiOperation("供应商-商品编辑回显（旧：/supplier/productInfo）")
    @ApiImplicitParam(required = true, name = "productId", value = "商品Id")
    @GetMapping("/product/form")
    public ResponseJson<ProductFormVo> getProductForm(Integer productId) {
        return shopService.getProductForm(productId);
    }

}
